@@ -1,7 +1,6 @@
-from tianshou import data, env, utils, policy, trainer, exploration
+from tianshou import data, env, exploration, policy, trainer, utils
 
-
-__version__ = "0.3.1"
+__version__ = "0.4.4"
 
 __all__ = [
     "env",
