@@ -1,6 +1,13 @@
-from tianshou.env.venvs import BaseVectorEnv, DummyVectorEnv, \
-    SubprocVectorEnv, ShmemVectorEnv, RayVectorEnv
+"""Env package."""
+
 from tianshou.env.maenv import MultiAgentEnv
+from tianshou.env.venvs import (
+    BaseVectorEnv,
+    DummyVectorEnv,
+    RayVectorEnv,
+    ShmemVectorEnv,
+    SubprocVectorEnv,
+)
 
 __all__ = [
     "BaseVectorEnv",
