@@ -1,10 +1,11 @@
 import time
+from typing import Any, Callable, Dict, Optional, Union
+
 import numpy as np
-from torch.utils.tensorboard import SummaryWriter
-from typing import Dict, List, Union, Callable, Optional
 
 from tianshou.data import Collector
 from tianshou.policy import BasePolicy
+from tianshou.utils import BaseLogger
 
 
 def test_episode(
@@ -12,25 +13,23 @@ def test_episode(
     collector: Collector,
     test_fn: Optional[Callable[[int, Optional[int]], None]],
     epoch: int,
-    n_episode: Union[int, List[int]],
-    writer: Optional[SummaryWriter] = None,
+    n_episode: int,
+    logger: Optional[BaseLogger] = None,
     global_step: Optional[int] = None,
-) -> Dict[str, float]:
+    reward_metric: Optional[Callable[[np.ndarray], np.ndarray]] = None,
+) -> Dict[str, Any]:
     """A simple wrapper of testing policy in collector."""
     collector.reset_env()
     collector.reset_buffer()
     policy.eval()
     if test_fn:
         test_fn(epoch, global_step)
-    if collector.get_env_num() > 1 and isinstance(n_episode, int):
-        n = collector.get_env_num()
-        n_ = np.zeros(n) + n_episode // n
-        n_[:n_episode % n] += 1
-        n_episode = list(n_)
     result = collector.collect(n_episode=n_episode)
-    if writer is not None and global_step is not None:
-        for k in result.keys():
-            writer.add_scalar("test/" + k, result[k], global_step=global_step)
+    if reward_metric:
+        rew = reward_metric(result["rews"])
+        result.update(rews=rew, rew=rew.mean(), rew_std=rew.std())
+    if logger and global_step is not None:
+        logger.log_test_data(result, global_step)
     return result
 
 
@@ -47,14 +46,14 @@ def gather_info(
 
         * ``train_step`` the total collected step of training collector;
         * ``train_episode`` the total collected episode of training collector;
-        * ``train_time/collector`` the time for collecting frames in the \
+        * ``train_time/collector`` the time for collecting transitions in the \
             training collector;
         * ``train_time/model`` the time for training models;
-        * ``train_speed`` the speed of training (frames per second);
+        * ``train_speed`` the speed of training (env_step per second);
         * ``test_step`` the total collected step of test collector;
         * ``test_episode`` the total collected episode of test collector;
         * ``test_time`` the time for testing;
-        * ``test_speed`` the speed of testing (frames per second);
+        * ``test_speed`` the speed of testing (env_step per second);
         * ``best_reward`` the best reward over the test results;
         * ``duration`` the total elapsed time.
     """
@@ -74,11 +73,13 @@ def gather_info(
     if train_c is not None:
         model_time -= train_c.collect_time
         train_speed = train_c.collect_step / (duration - test_c.collect_time)
-        result.update({
-            "train_step": train_c.collect_step,
-            "train_episode": train_c.collect_episode,
-            "train_time/collector": f"{train_c.collect_time:.2f}s",
-            "train_time/model": f"{model_time:.2f}s",
-            "train_speed": f"{train_speed:.2f} step/s",
-        })
+        result.update(
+            {
+                "train_step": train_c.collect_step,
+                "train_episode": train_c.collect_episode,
+                "train_time/collector": f"{train_c.collect_time:.2f}s",
+                "train_time/model": f"{model_time:.2f}s",
+                "train_speed": f"{train_speed:.2f} step/s",
+            }
+        )
     return result
